@@ -2,7 +2,7 @@
 # plugin.sh - devstack plugin for ironic
 
 # devstack plugin contract defined at:
-# http://docs.openstack.org/developer/devstack/plugins.html
+# https://docs.openstack.org/devstack/latest/plugins.html
 
 echo_summary "ironic devstack plugin.sh called: $1/$2"
 source $DEST/ironic/devstack/lib/ironic
@@ -19,6 +19,10 @@ if is_service_enabled ir-api ir-cond; then
         # their dependencies have been installed
 
             echo_summary "Installing Ironic"
+            if ! is_service_enabled nova; then
+                source $RC_DIR/lib/nova_plugins/functions-libvirt
+                install_libvirt
+            fi
             install_ironic
             install_ironicclient
             cleanup_ironic_config_files
