@@ -7,12 +7,15 @@
 
 set -exu
 
+# Make tracing more educational
+export PS4='+ ${BASH_SOURCE:-}:${FUNCNAME[0]:-}:L${LINENO:-}:   '
+
 LIBVIRT_CONNECT_URI=${LIBVIRT_CONNECT_URI:-"qemu:///system"}
 
 # Keep track of the DevStack directory
 TOP_DIR=$(cd $(dirname "$0")/.. && pwd)
-BRIDGE_SUFFIX=${1:-''}
-BRIDGE_NAME=brbm$BRIDGE_SUFFIX
+BRIDGE_NAME=${1:-brbm}
+PUBLIC_BRIDGE_MTU=${2:-1500}
 
 export VIRSH_DEFAULT_CONNECT_URI="$LIBVIRT_CONNECT_URI"
 
@@ -27,3 +30,5 @@ sudo ip link set dev ${BRIDGE_NAME} up
 virsh net-define <(sed s/brbm/$BRIDGE_NAME/ $TOP_DIR/templates/brbm.xml)
 virsh net-autostart ${BRIDGE_NAME}
 virsh net-start ${BRIDGE_NAME}
+
+sudo ip link set dev ${BRIDGE_NAME} mtu $PUBLIC_BRIDGE_MTU
